#!/bin/bash
#
# This script is executed only once, just before the app partition
# will be erased (/usr/local).
#
# update: clean rootfs space in downgrade scenario

## FUNCTIONS ##
function downgradeOlder2102() {
	### 21.02
	##### New Management features in recovery mode
	##### downgrade scenario: remove all management related files 
	mount -o remount,rw /
	for file in "backupManagement.php"; do
		if [ -f /usr/php/$file ]; then
			rm -f /usr/php/$file
		fi
	done
	for file in "recovery-mode.sh"; do
		if [ -f /usr/sbin/$file ]; then
			rm -f /usr/sbin/$file
		fi
	done
	for file in "backup.php" "management.php"; do
		if [ -f /usr/www/cgi-bin/$file ]; then
			rm -f /usr/www/cgi-bin/$file
		fi
	done
	## older than 21.02 is 20.05.X. So all packages are gonna be installed
	## no need to dicrease the PKG_VERSION values
}

function downgradeOlder2103() {
	### 21.03
	#####
	##### New rootfs organization (cloud features moved from appfs to rootfs)
	##### downgrade scenario: we remove the new files

	##### New tftp flashing features in recovery mode
	##### downgrade scenario: remove all flashing related files

	mount -o remount,rw /
	for file in "S36cron" "S44redirect" "S45provisioning" "S65cloud"; do
		if [ -f /etc/init.d/$file ]; then
			rm -f /etc/init.d/$file
		fi
	done
	for file in "cloud.php" "redirect.php" "include/SbcApi.php" "include/beroCloudAPI.php" "include/rootHelper.class.php"; do 
		if [ -f /usr/php/$file ]; then
			rm -f /usr/php/$file
		fi
	done
	for file in "cloud" "reproduce.sh" "fw_printenv" "fw_setenv"; do
		if [ -f /usr/fallback/$file ]; then
			rm -f /usr/fallback/$file
		fi
	done
	for file in "remotesupport.sh" "recovery-mode.sh"; do
		if [ -f /usr/sbin/$file ]; then
			rm -f /usr/sbin/$file
		fi
	done
	for file in "reproduce.php"; do
		if [ -f /usr/www/cgi-bin/$file ]; then
			rm -f /usr/www/cgi-bin/$file
		fi
	done
	# force to reinstall rootfs/recovery-gui (maybe find a better spot or mechanism to do so)
	for file in "rootfs" "recoverygui"; do
		/bin/sed -i 's/PKG_VERSION=.*/PKG_VERSION=1/g' /pkginfo/VERSION.$file
	done
	# remove /usr/fallback/cloud task from crontab
	crontab -l | grep -v 'fallback/cloud api' > /tmp/crontab.downgrade
	crontab /tmp/crontab.downgrade
	rm -f /tmp/crontab.downgrade
	mount -o remount,ro /
}

## MAIN ##
if [ -z ${2} ]; then
	## old code
	APPFS_TO_INSTALL=${1}
	if [ -z ${APPFS_TO_INSTALL} ]; then
		APPFS_TO_INSTALL=1
	fi

	# we re-install all rootfs-packages from appfs3 or younger
	if [ ${APPFS_TO_INSTALL} -le 3 ]; then
		# as we remove /pkginfo it's better to set boot_fwupdate to 0 now
		/usr/fallback/beroconf set root boot_fwupdate 0

		# removing rootfs-stuff that would come in our downgrade-way
		mount -oremount,rw /
		rm -rf /pkginfo
		rm -f /etc/init.d/S30berofix-fpga
		rm -f /lib/modules/berofix-fpga.ko
		mount -oremount,ro /
	fi
else
	## new code
	APPFS=${1}
	MINOR=${2}

	if [ "${APPFS}" -lt "21" ]; then
		downgradeOlder2103
		downgradeOlder2102
	elif [[ "${APPFS}" = "21" ]] && [[ "${MINOR}" -lt "03"	]]; then
		downgradeOlder2103
	fi
fi
